hotspot/src/share/vm/gc_implementation/g1/g1MMUTracker.cpp
changeset 5033 55f476a32544
parent 4458 075a9ef4e467
child 5714 f8777c8c7a3b
child 5547 f4b087cbb361
--- a/hotspot/src/share/vm/gc_implementation/g1/g1MMUTracker.cpp	Tue Feb 16 14:11:44 2010 -0800
+++ b/hotspot/src/share/vm/gc_implementation/g1/g1MMUTracker.cpp	Tue Feb 23 23:13:23 2010 -0500
@@ -88,13 +88,13 @@
     //     the time slice than what's allowed)
     //   consolidate the two entries with the minimum gap between them
     //     (this might allow less GC time than what's allowed)
-    guarantee(NOT_PRODUCT(ScavengeALot ||) G1ForgetfulMMUTracker,
-              "array full, currently we can't recover unless +G1ForgetfulMMUTracker");
+    guarantee(NOT_PRODUCT(ScavengeALot ||) G1UseFixedWindowMMUTracker,
+              "array full, currently we can't recover unless +G1UseFixedWindowMMUTracker");
     // In the case where ScavengeALot is true, such overflow is not
     // uncommon; in such cases, we can, without much loss of precision
     // or performance (we are GC'ing most of the time anyway!),
     // simply overwrite the oldest entry in the tracker: this
     // is also the behaviour when G1ForgetfulMMUTracker is enabled.
     _head_index = trim_index(_head_index + 1);
     assert(_head_index == _tail_index, "Because we have a full circular buffer");
     _tail_index = trim_index(_tail_index + 1);
@@ -88,13 +88,13 @@
     // or performance (we are GC'ing most of the time anyway!),
     // simply overwrite the oldest entry in the tracker: this
-    // is also the behaviour when G1ForgetfulMMUTracker is enabled.
+    // is also the behaviour when G1UseFixedWindowMMUTracker is enabled.
     _head_index = trim_index(_head_index + 1);
     assert(_head_index == _tail_index, "Because we have a full circular buffer");